summaryrefslogtreecommitdiffstats
path: root/akregator/src/akregator_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/akregator_view.h')
-rw-r--r--akregator/src/akregator_view.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/akregator/src/akregator_view.h b/akregator/src/akregator_view.h
index 66796d42..c6e94eb0 100644
--- a/akregator/src/akregator_view.h
+++ b/akregator/src/akregator_view.h
@@ -85,11 +85,11 @@ namespace Akregator {
/** constructor
@param part the Akregator::Part which contains this widget
- @param tqparent tqparent widget
+ @param parent parent widget
@param Actionmanager for this view
@param name the name of the widget (@ref TQWidget )
*/
- View(Akregator::Part *part, TQWidget *tqparent, ActionManagerImpl* actionManager, const char* name);
+ View(Akregator::Part *part, TQWidget *parent, ActionManagerImpl* actionManager, const char* name);
/** destructor. Note that cleanups should be done in
slotOnShutdown(), so we don't risk accessing self-deleting objects after deletion. */
@@ -104,11 +104,11 @@ namespace Akregator {
@param doc the DOM tree (OPML) of the feeds to import */
bool importFeeds(const TQDomDocument& doc);
/** Parse OPML presentation of feeds and read in articles archive, if present. If @c tqparent is @c NULL, the current
feed list is replaced by the parsed one
@param doc TQDomDocument generated from OPML
- @param tqparent The tqparent group the new nodes */
- bool loadFeeds(const TQDomDocument& doc, Folder* tqparent = 0);
+ @param parent The parent group the new nodes */
+ bool loadFeeds(const TQDomDocument& doc, Folder* parent = 0);
/**
@return the displayed Feed List in OPML format
@@ -190,7 +190,7 @@ namespace Akregator {
void slotCaptionChanged(const TQString &);
/** called when URLs are dropped into the tree view */
- void slotFeedURLDropped (KURL::List &urls, TreeNode* after, Folder *tqparent);
+ void slotFeedURLDropped (KURL::List &urls, TreeNode* after, Folder *parent);
/** displays a URL in the status bar when the user moves the mouse over a link */
void slotMouseOverInfo(const KFileItem *kifi);
@@ -272,7 +272,7 @@ namespace Akregator {
protected:
- void addFeed(const TQString& url, TreeNode* after, Folder* tqparent, bool autoExec = true);
+ void addFeed(const TQString& url, TreeNode* after, Folder* parent, bool autoExec = true);
void connectToFeedList(FeedList* feedList);
void disconnectFromFeedList(FeedList* feedList);
@@ -104,11 +104,11 @@ namespace Akregator {
bool importFeeds(const TQDomDocument& doc);
- /** Parse OPML presentation of feeds and read in articles archive, if present. If @c tqparent is @c NULL, the current
+ /** Parse OPML presentation of feeds and read in articles archive, if present. If @c parent is @c NULL, the current
feed list is replaced by the parsed one